@@ -44,8 +44,8 @@ Conf::Conf()
 
 #if defined(__linux__) || defined(__APPLE__)
 
-	confFilePath = gGetHomePath() + gGetSlash() + CONF_FILENAME;
-	confDirPath  = gGetHomePath() + gGetSlash();
+	confFilePath = gGetHomePath() + G_SLASH + CONF_FILENAME;
+	confDirPath  = gGetHomePath() + G_SLASH;
 
 #elif defined(_WIN32)
 
@@ -102,12 +102,12 @@ void Conf::init()
 	limitOutput    = false;
 	rsmpQuality    = 0;
 
-	midiPortIn     = DEFAULT_MIDI_PORT_IN;
-	noNoteOff      = false;
-	midiMapPath    = "";
-	midiPortOut    = DEFAULT_MIDI_PORT_OUT;
-	midiSync       = MIDI_SYNC_NONE;
-	midiTCfps      = 25.0f;
+	midiPortIn  = DEFAULT_MIDI_PORT_IN;
+	noNoteOff   = false;
+	midiMapPath = "";
+	midiPortOut = DEFAULT_MIDI_PORT_OUT;
+	midiSync    = MIDI_SYNC_NONE;
+	midiTCfps   = 25.0f;
 
 	midiInRewind     = 0x0;
 	midiInStartStop  = 0x0;
@@ -129,17 +129,43 @@ void Conf::init()
 
 	resizeRecordings = true;
 
-	actionEditorZoom    = 100;
-	actionEditorGridOn  = false;
-	actionEditorGridVal = 1;
-
 	mainWindowX = 0;
 	mainWindowY = 0;
 	mainWindowW = GUI_WIDTH;
 	mainWindowH = GUI_HEIGHT;
 
+	browserX         = 0;
+	browserY         = 0;
+	browserW         = 640;
+	browserH         = 480;
+	browserPosition  = 0;
+	browserLastValue = 0;
+
+	actionEditorX       = 0;
+	actionEditorY       = 0;
+	actionEditorW       = 640;
+	actionEditorH       = 480;
+	actionEditorZoom    = 100;
+	actionEditorGridOn  = false;
+	actionEditorGridVal = 1;
+
+	sampleEditorX = 0;
+	sampleEditorY = 0;
+	sampleEditorW = 640;
+	sampleEditorH = 480;
+
 	pianoRollY = -1;
 	pianoRollH = 422;
+
+	#ifdef WITH_VST
+
+	pluginChooserX   = 0;
+	pluginChooserY   = 0;
+	pluginChooserW   = 640;
+	pluginChooserH   = 480;
+	pluginSortMethod = 0;
+
+	#endif
 }
 
 
@@ -206,6 +232,9 @@ int Conf::read()
 	if (!setInt(jRoot, CONF_KEY_BROWSER_Y, browserY)) return 0;
 	if (!setInt(jRoot, CONF_KEY_BROWSER_W, browserW)) return 0;
 	if (!setInt(jRoot, CONF_KEY_BROWSER_H, browserH)) return 0;
+	if (!setInt(jRoot, CONF_KEY_BROWSER_POSITION, browserPosition)) return 0;
+	if (!setString(jRoot, CONF_KEY_BROWSER_LAST_PATH, browserLastPath)) return 0;
+	if (!setInt(jRoot, CONF_KEY_BROWSER_LAST_VALUE, browserLastValue)) return 0;
 	if (!setInt(jRoot, CONF_KEY_ACTION_EDITOR_X, actionEditorX)) return 0;
 	if (!setInt(jRoot, CONF_KEY_ACTION_EDITOR_Y, actionEditorY)) return 0;
 	if (!setInt(jRoot, CONF_KEY_ACTION_EDITOR_W, actionEditorW)) return 0;
@@ -232,6 +261,16 @@ int Conf::read()
 	if (!setInt(jRoot, CONF_KEY_ABOUT_X, aboutX)) return 0;
 	if (!setInt(jRoot, CONF_KEY_ABOUT_Y, aboutY)) return 0;
 
+#ifdef WITH_VST
+
+	if (!setInt(jRoot, CONF_KEY_PLUGIN_CHOOSER_X, pluginChooserX)) return 0;
+	if (!setInt(jRoot, CONF_KEY_PLUGIN_CHOOSER_Y, pluginChooserY)) return 0;
+	if (!setInt(jRoot, CONF_KEY_PLUGIN_CHOOSER_W, pluginChooserW)) return 0;
+	if (!setInt(jRoot, CONF_KEY_PLUGIN_CHOOSER_H, pluginChooserH)) return 0;
+	if (!setInt(jRoot, CONF_KEY_PLUGIN_SORT_METHOD, pluginSortMethod)) return 0;
+
+#endif
+
 	json_decref(jRoot);
 
 	sanitize();
@@ -294,6 +333,9 @@ int Conf::write()
 	json_object_set_new(jRoot, CONF_KEY_BROWSER_Y,                 json_integer(browserY));
 	json_object_set_new(jRoot, CONF_KEY_BROWSER_W,                 json_integer(browserW));
 	json_object_set_new(jRoot, CONF_KEY_BROWSER_H,                 json_integer(browserH));
+	json_object_set_new(jRoot, CONF_KEY_BROWSER_POSITION,          json_integer(browserPosition));
+	json_object_set_new(jRoot, CONF_KEY_BROWSER_LAST_PATH,         json_string(browserLastPath.c_str()));
+	json_object_set_new(jRoot, CONF_KEY_BROWSER_LAST_VALUE,        json_integer(browserLastValue));
 	json_object_set_new(jRoot, CONF_KEY_ACTION_EDITOR_X,           json_integer(actionEditorX));
 	json_object_set_new(jRoot, CONF_KEY_ACTION_EDITOR_Y,           json_integer(actionEditorY));
 	json_object_set_new(jRoot, CONF_KEY_ACTION_EDITOR_W,           json_integer(actionEditorW));
@@ -320,6 +362,16 @@ int Conf::write()
 	json_object_set_new(jRoot, CONF_KEY_ABOUT_X,                   json_integer(aboutX));
 	json_object_set_new(jRoot, CONF_KEY_ABOUT_Y,                   json_integer(aboutY));
 
+#ifdef WITH_VST
+
+	json_object_set_new(jRoot, CONF_KEY_PLUGIN_CHOOSER_X,   json_integer(pluginChooserX));
+	json_object_set_new(jRoot, CONF_KEY_PLUGIN_CHOOSER_Y,   json_integer(pluginChooserY));
+	json_object_set_new(jRoot, CONF_KEY_PLUGIN_CHOOSER_W,   json_integer(pluginChooserW));
+	json_object_set_new(jRoot, CONF_KEY_PLUGIN_CHOOSER_H,   json_integer(pluginChooserH));
+	json_object_set_new(jRoot, CONF_KEY_PLUGIN_SORT_METHOD, json_integer(pluginSortMethod));
+
+#endif
+
   if (json_dump_file(jRoot, confFilePath.c_str(), JSON_INDENT(2)) != 0) {
     gLog("[Conf::write] unable to write configuration file!\n");
     return 0;
