@@ -32,16 +32,24 @@
 
 
 /* -- version --------------------------------------------------------------- */
-#define G_VERSION_STR   "0.12.2"
+#define G_VERSION_STR   "0.13.0"
 #define G_APP_NAME      "Giada"
 #define G_VERSION_MAJOR 0
-#define G_VERSION_MINOR 12
-#define G_VERSION_PATCH 2
+#define G_VERSION_MINOR 13
+#define G_VERSION_PATCH 0
 
 #define CONF_FILENAME		"giada.conf"
 
 #ifndef BUILD_DATE
-# define BUILD_DATE __DATE__
+	#define BUILD_DATE __DATE__
+#endif
+
+#ifdef _WIN32
+	#define G_SLASH '\\'
+	#define G_SLASH_STR "\\"
+#else
+	#define G_SLASH '/'
+	#define G_SLASH_STR "/"
 #endif
 
 
@@ -420,6 +428,9 @@ const int MIDI_CHANS[16] = {
 #define CONF_KEY_BROWSER_Y                "browser_y"
 #define CONF_KEY_BROWSER_W                "browser_w"
 #define CONF_KEY_BROWSER_H                "browser_h"
+#define CONF_KEY_BROWSER_POSITION         "browser_position"
+#define CONF_KEY_BROWSER_LAST_PATH        "browser_last_path"
+#define CONF_KEY_BROWSER_LAST_VALUE       "browser_last_value"
 #define CONF_KEY_ACTION_EDITOR_X          "action_editor_x"
 #define CONF_KEY_ACTION_EDITOR_Y          "action_editor_y"
 #define CONF_KEY_ACTION_EDITOR_W          "action_editor_w"
