@@ -32,15 +32,7 @@
 
 
 #ifdef WITH_VST
-// TODO - can we move this stuff to a separate file?
-#include "../deps/juce/juce_audio_basics/juce_audio_basics.h"
-#include "../deps/juce/juce_audio_processors/juce_audio_processors.h"
-#include "../deps/juce/juce_core/juce_core.h"
-#include "../deps/juce/juce_data_structures/juce_data_structures.h"
-#include "../deps/juce/juce_events/juce_events.h"
-#include "../deps/juce/juce_graphics/juce_graphics.h"
-#include "../deps/juce/juce_gui_basics/juce_gui_basics.h"
-#include "../deps/juce/juce_gui_extra/juce_gui_extra.h"
+	#include "../deps/juce/config.h"
 #endif
 
 #include "channel.h"
