@@ -41,17 +41,24 @@ int Plugin::idGenerator = 1;
 /* -------------------------------------------------------------------------- */
 
 
-void Plugin::initEditor()
+void Plugin::init()
 {
+  ui     = NULL;
+  id     = idGenerator++;;
+  bypass = false;
+  status = 1;
+
   if (getActiveEditor() != NULL) {
-    gLog("[Plugin::initEditor] plugin has an already active editor!\n");
+    gLog("[Plugin::init] plugin has an already active editor!\n");
     return;
   }
-  ui = createEditor();
+  ui = createEditorIfNeeded();
   if (ui == NULL) {
-    gLog("[Plugin::initEditor] unable to create editor!\n");
+    gLog("[Plugin::init] unable to create editor, the plugin might be GUI-less!\n");
     return;
   }
+
+  gLog("[Plugin::init] editor initialized and ready\n");
 }
 
 
@@ -65,7 +72,6 @@ void Plugin::showEditor(void *parent)
     return;
   }
   ui->setOpaque(true);
-  ui->setVisible(true);
   ui->addToDesktop(0, parent);
 }
 
@@ -75,7 +81,7 @@ void Plugin::showEditor(void *parent)
 
 bool Plugin::isEditorOpen()
 {
-  return ui->isVisible();
+  return ui->isVisible() && ui->isOnDesktop();
 }
 
 
@@ -95,7 +101,6 @@ void Plugin::closeEditor()
 {
   if (ui == NULL)
     return;
-  ui->setVisible(false);
   if (ui->isOnDesktop())
   	ui->removeFromDesktop();
 }
