@@ -62,7 +62,7 @@ void PluginHost::init(int _buffersize, int _samplerate)
   buffersize = _buffersize;
   missingPlugins = false;
   //unknownPluginList.empty();
-  loadList(gGetHomePath() + gGetSlash() + "plugins.xml");
+  loadList(gGetHomePath() + G_SLASH + "plugins.xml");
 }
 
 
@@ -151,8 +151,10 @@ Plugin *PluginHost::addPlugin(const string &fid, int stackType,
     return NULL;
   }
 
-  p->setStatus(1);
-  p->setId();
+  //p->setStatus(1);
+  //p->setId();
+  //p->initEditor();
+  p->init();
   p->prepareToPlay(samplerate, buffersize);
 
   gLog("[PluginHost::addPlugin] plugin instance with fid=%s created\n", fid.c_str());
