@@ -34,6 +34,7 @@
 #include "../utils/gui_utils.h"
 #include "../core/mixerHandler.h"
 #include "../core/mixer.h"
+#include "../core/pluginHost.h"
 #include "../core/conf.h"
 #include "../core/channel.h"
 #include "../core/sampleChannel.h"
@@ -45,6 +46,9 @@
 extern gdMainWindow *mainWin;
 extern Conf          G_Conf;
 extern Mixer	   		 G_Mixer;
+#ifdef WITH_VST
+extern PluginHost G_PluginHost;
+#endif
 
 
 using std::string;
@@ -57,7 +61,7 @@ int glue_loadChannel(SampleChannel *ch, const char *fname)
 
 	G_Conf.samplePath = gDirname(fname);
 
-	int result = ch->load(fname);
+	int result = ch->load(fname, G_Conf.samplerate, G_Conf.rsmpQuality);
 
 	if (result == SAMPLE_LOADED_OK)
 		mainWin->keyboard->updateChannel(ch->guiChannel);
@@ -84,8 +88,10 @@ Channel *glue_addChannel(int column, int type)
 
 void glue_deleteChannel(Channel *ch)
 {
-	int index = ch->index;
-	recorder::clearChan(index);
+	recorder::clearChan(ch->index);
+#ifdef WITH_VST
+	G_PluginHost.freeStack(PluginHost::CHANNEL, &G_Mixer.mutex_plugins, ch);
+#endif
 	Fl::lock();
 	mainWin->keyboard->deleteChannel(ch->guiChannel);
 	Fl::unlock();
@@ -99,6 +105,9 @@ void glue_deleteChannel(Channel *ch)
 
 void glue_freeChannel(Channel *ch)
 {
+#ifdef WITH_VST
+	G_PluginHost.freeStack(PluginHost::CHANNEL, &G_Mixer.mutex_plugins, ch);
+#endif
 	mainWin->keyboard->freeChannel(ch->guiChannel);
 	recorder::clearChan(ch->index);
 	ch->empty();
@@ -114,7 +123,7 @@ int glue_cloneChannel(Channel *src)
 	gChannel *gch  = mainWin->keyboard->addChannel(src->guiChannel->getColumnIndex(), ch);
 
 	ch->guiChannel = gch;
-	ch->copy(src);
+	ch->copy(src, &G_Mixer.mutex_plugins);
 
 	mainWin->keyboard->updateChannel(ch->guiChannel);
 	return true;
