@@ -32,6 +32,7 @@
 #include "../gui/elems/ge_keyboard.h"
 #include "../gui/dialogs/gd_mainWindow.h"
 #include "../gui/dialogs/gd_warnings.h"
+#include "../gui/dialogs/gd_browser.h"
 #include "../core/mixer.h"
 #include "../core/mixerHandler.h"
 #include "../core/channel.h"
@@ -62,17 +63,6 @@ extern PluginHost    G_PluginHost;
 #endif
 
 
-static void __glue_setProgressBar__(class gProgress *status, float v)
-{
-	status->value(status->value() + v);
-	//Fl::check();
-	Fl::wait(0);
-}
-
-
-/* -------------------------------------------------------------------------- */
-
-
 #ifdef WITH_VST
 
 static void __glue_fillPatchGlobalsPlugins__(vector <Plugin *> *host, vector<Patch::plugin_t> *patch)
@@ -160,7 +150,8 @@ static void __glue_fillPatchGlobals__(const string &name)
 /* -------------------------------------------------------------------------- */
 
 
-int glue_savePatch(const string &fullPath, const string &name, bool isProject)
+static bool __glue_savePatch__(const string &fullPath, const string &name,
+		bool isProject)
 {
 	G_Patch.init();
 
@@ -170,38 +161,88 @@ int glue_savePatch(const string &fullPath, const string &name, bool isProject)
 
 	if (G_Patch.write(fullPath)) {
 		gu_update_win_label(name.c_str());
-		gLog("[glue] patch saved as %s\n", fullPath.c_str());
-		return 1;
+		gLog("[glue_savePatch] patch saved as %s\n", fullPath.c_str());
+		return true;
 	}
-	return 0;
+	return false;
 }
 
 
 /* -------------------------------------------------------------------------- */
 
 
-int glue_loadPatch(const string &fullPath, class gProgress *status, bool isProject)
+void glue_savePatch(void *data)
 {
-	/* try to load the new JSON-based patch. If it fails, fall back to deprecated
-	* one. */
+	gdSaveBrowser *browser = (gdSaveBrowser*) data;
+	string name            = browser->getName();
+	string fullPath        = browser->getCurrentPath() + G_SLASH + gStripExt(name) + ".gptc";
+
+	if (name == "") {
+		gdAlert("Please choose a file name.");
+		return;
+	}
+
+	if (gFileExists(fullPath.c_str()))
+		if (!gdConfirmWin("Warning", "File exists: overwrite?"))
+			return;
+
+	if (__glue_savePatch__(fullPath, name, false)) {  // false == not a project
+		G_Conf.patchPath = gDirname(fullPath);
+		browser->do_callback();
+	}
+	else
+		gdAlert("Unable to save the patch!");
+}
+
+
+/* -------------------------------------------------------------------------- */
+
+
+void glue_loadPatch(void *data)
+{
+	gdLoadBrowser *browser = (gdLoadBrowser*) data;
+	string fullPath        = browser->getSelectedItem();
+	bool isProject         = gIsProject(browser->getSelectedItem());
+
+	browser->showStatusBar();
 
 	gLog("[glue] loading %s...\n", fullPath.c_str());
 
 	string fileToLoad = fullPath;  // patch file to read from
 	string basePath   = "";        // base path, in case of reading from a project
 	if (isProject) {
-		fileToLoad = fullPath + gGetSlash() + gStripExt(gBasename(fullPath)) + ".gptc";
-		basePath   = fullPath.c_str() + gGetSlash();
+		fileToLoad = fullPath + G_SLASH + gStripExt(gBasename(fullPath)) + ".gptc";
+		basePath   = fullPath + G_SLASH;
 	}
 
-	int res = G_Patch.read(fileToLoad);
+	/* try to load the new JSON-based patch. If it fails, fall back to deprecated
+	* one. */
+
+	int  res = G_Patch.read(fileToLoad);
+	bool deprecated = false;
 
 	if (res == PATCH_UNREADABLE) {
 		gLog("[glue] failed reading JSON-based patch. Trying with the deprecated method\n");
-		return glue_loadPatch__DEPR__(gBasename(fileToLoad).c_str(), fileToLoad.c_str(), status, isProject);
+		deprecated = true;
+		res = glue_loadPatch__DEPR__(gBasename(fileToLoad).c_str(), fileToLoad.c_str(),
+				browser->getStatusBar(), isProject);
+	}
+
+	if (res != PATCH_READ_OK) {
+		if (res == PATCH_UNREADABLE)
+			isProject ? gdAlert("This project is unreadable.") : gdAlert("This patch is unreadable.");
+		else
+		if (res == PATCH_INVALID)
+			isProject ? gdAlert("This project is not valid.") : gdAlert("This patch is not valid.");
+
+		browser->hideStatusBar();
+		return;
+	}
+	else
+	if (deprecated) {
+		browser->do_callback();
+		return;
 	}
-	if (res != PATCH_READ_OK)
-		return res;
 
 	/* close all other windows. This prevents segfault if plugin
 	 * windows GUIs are on. */
@@ -213,7 +254,8 @@ int glue_loadPatch(const string &fullPath, class gProgress *status, bool isProje
 
 	glue_resetToInitState(false, false);
 
-	__glue_setProgressBar__(status, 0.1f);
+	browser->setStatusBar(0.1f);
+	//__glue_setProgressBar__(status, 0.1f);
 
 	/* Add common stuff, columns and channels. Also increment the progress bar
 	 * by 0.8 / total_channels steps.  */
@@ -229,7 +271,8 @@ int glue_loadPatch(const string &fullPath, class gProgress *status, bool isProje
 				ch->readPatch(basePath, k, &G_Patch, &G_Mixer.mutex_plugins,
 						G_Conf.samplerate, G_Conf.rsmpQuality);
 			}
-			__glue_setProgressBar__(status, steps);
+			//__glue_setProgressBar__(status, steps);
+			browser->setStatusBar(steps);
 		}
 	}
 
@@ -245,14 +288,15 @@ int glue_loadPatch(const string &fullPath, class gProgress *status, bool isProje
 	/* save patchPath by taking the last dir of the broswer, in order to
 	 * reuse it the next time */
 
-	G_Conf.patchPath = gDirname(fullPath.c_str());
+	G_Conf.patchPath = gDirname(fullPath);
 
 	/* refresh GUI */
 
 	gu_updateControls();
 	gu_update_win_label(G_Patch.name.c_str());
 
-	__glue_setProgressBar__(status, 1.0f);
+	browser->setStatusBar(0.1f);
+	//__glue_setProgressBar__(status, 1.0f);
 
 	gLog("[glue] patch loaded successfully\n");
 
@@ -263,7 +307,7 @@ int glue_loadPatch(const string &fullPath, class gProgress *status, bool isProje
 
 #endif
 
-	return res;
+	browser->do_callback();
 }
 
 
@@ -359,13 +403,28 @@ int glue_loadPatch__DEPR__(const char *fname, const char *fpath, gProgress *stat
 /* -------------------------------------------------------------------------- */
 
 
-int glue_saveProject(const string &folderPath, const string &projName)
+void glue_saveProject(void *data)
 {
-	if (!gDirExists(folderPath.c_str()) && !gMkdir(folderPath.c_str())) {
-		gLog("[glue] unable to make project directory!\n");
-		return 0;
+	gdSaveBrowser *browser = (gdSaveBrowser*) data;
+	string name            = browser->getName();
+	string folderPath      = browser->getCurrentPath(); //browser->getSelectedItem();
+	string fullPath        = folderPath + G_SLASH + gStripExt(name) + ".gprj";
+
+	if (name == "") {
+		gdAlert("Please choose a project name.");
+		return;
 	}
 
+	if (gIsProject(fullPath.c_str()) && !gdConfirmWin("Warning", "Project exists: overwrite?"))
+		return;
+
+	if (!gDirExists(fullPath.c_str()) && !gMkdir(fullPath.c_str())) {
+		gLog("[glue_saveProject] unable to make project directory!\n");
+		return;
+	}
+
+	gLog("[glue_saveProject] project dir created: %s\n", fullPath.c_str());
+
 	/* copy all samples inside the folder. Takes and logical ones are saved
 	 * via glue_saveSample() */
 
@@ -382,7 +441,7 @@ int glue_saveProject(const string &folderPath, const string &projName)
 		/* update the new samplePath: everything now comes from the project
 		 * folder (folderPath). Also remove any existing file. */
 
-		string samplePath = folderPath + gGetSlash() + ch->wave->basename() + "." + ch->wave->extension();
+		string samplePath = fullPath + G_SLASH + ch->wave->basename(true);
 
 		if (gFileExists(samplePath.c_str()))
 			remove(samplePath.c_str());
@@ -390,8 +449,63 @@ int glue_saveProject(const string &folderPath, const string &projName)
 			ch->wave->pathfile = samplePath;
 	}
 
-	string gptcPath = folderPath + gGetSlash() + gStripExt(projName.c_str()) + ".gptc";
-	glue_savePatch(gptcPath, projName, true); // true == it's a project
+	string gptcPath = fullPath + G_SLASH + gStripExt(name.c_str()) + ".gptc";
+	if (__glue_savePatch__(gptcPath, name, true)) // true == it's a project
+		browser->do_callback();
+	else
+		gdAlert("Unable to save the project!");
+}
 
-	return 1;
+
+/* -------------------------------------------------------------------------- */
+
+
+void glue_loadSample(void *data)
+{
+	gdLoadBrowser *browser = (gdLoadBrowser*) data;
+	string fullPath        = browser->getSelectedItem();
+
+	if (fullPath.empty())
+		return;
+
+	int res = glue_loadChannel((SampleChannel*) browser->getChannel(), fullPath.c_str());
+
+	if (res == SAMPLE_LOADED_OK) {
+		G_Conf.samplePath = gDirname(fullPath);
+		browser->do_callback();
+		mainWin->delSubWindow(WID_SAMPLE_EDITOR); // if editor is open
+	}
+	else
+		mainWin->keyboard->printChannelMessage(res);
+}
+
+
+/* -------------------------------------------------------------------------- */
+
+
+void glue_saveSample(void *data)
+{
+	gdSaveBrowser *browser = (gdSaveBrowser*) data;
+	string name            = browser->getName();
+	string folderPath      = browser->getSelectedItem();
+
+	if (name == "") {
+		gdAlert("Please choose a file name.");
+		return;
+	}
+
+	/* bruteforce check extension. */
+
+	string filePath = folderPath + G_SLASH + gStripExt(name) + ".wav";
+
+	if (gFileExists(filePath))
+		if (!gdConfirmWin("Warning", "File exists: overwrite?"))
+			return;
+
+	if (((SampleChannel*)browser->getChannel())->save(filePath.c_str())) {
+		G_Conf.samplePath = gDirname(folderPath);
+		browser->do_callback();
+	}
+	else
+		gdAlert("Unable to save this sample!");
 }
