@@ -43,6 +43,7 @@
 #include "../../core/conf.h"
 #include "../../core/pluginHost.h"
 #include "../../glue/glue.h"
+#include "../../glue/storage.h"
 #include "../elems/ge_keyboard.h"
 #include "gd_warnings.h"
 #include "gd_bpmInput.h"
@@ -57,6 +58,7 @@
 
 extern Mixer	   		 G_Mixer;
 extern Patch_DEPR_   G_Patch_DEPR_;
+extern Patch         G_Patch;
 extern Conf	 	   		 G_Conf;
 extern gdMainWindow *mainWin;
 extern bool	 		 		 G_quit;
@@ -67,6 +69,7 @@ gdMainWindow::gdMainWindow(int W, int H, const char *title, int argc, char **arg
 	: gWindow(W, H, title)
 {
 	Fl::visible_focus(0);
+
 	Fl::background(25, 25, 25);
 	Fl::set_boxtype(G_BOX, gDrawBox, 1, 1, 2, 2);    // custom box G_BOX
 
@@ -109,6 +112,7 @@ gdMainWindow::gdMainWindow(int W, int H, const char *title, int argc, char **arg
 	add(keyboard);
 	callback(cb_endprogram);
 	gu_setFavicon(this);
+
 	show(argc, argv);
 }
 
@@ -317,7 +321,11 @@ void gMenu::__cb_file()
 
 
 	if (strcmp(m->label(), "Open patch or project...") == 0) {
-		gWindow *childWin = new gdBrowser("Load Patch", G_Conf.patchPath.c_str(), 0, BROWSER_LOAD_PATCH);
+		//gWindow *childWin = new gdBrowser("Load Patch", G_Conf.patchPath.c_str(), 0, BROWSER_LOAD_PATCH);
+		//gu_openSubWindow(mainWin, childWin, WID_FILE_BROWSER);
+		gWindow *childWin = new gdLoadBrowser(G_Conf.browserX, G_Conf.browserY,
+				G_Conf.browserW, G_Conf.browserH, "Load patch or project",
+				G_Conf.patchPath, glue_loadPatch, NULL);
 		gu_openSubWindow(mainWin, childWin, WID_FILE_BROWSER);
 		return;
 	}
@@ -325,12 +333,16 @@ void gMenu::__cb_file()
 		if (G_Mixer.hasLogicalSamples() || G_Mixer.hasEditedSamples())
 			if (!gdConfirmWin("Warning", "You should save a project in order to store\nyour takes and/or processed samples."))
 				return;
-		gWindow *childWin = new gdBrowser("Save Patch", G_Conf.patchPath.c_str(), 0, BROWSER_SAVE_PATCH);
+		gWindow *childWin = new gdSaveBrowser(G_Conf.browserX, G_Conf.browserY,
+				G_Conf.browserW, G_Conf.browserH, "Save patch",
+				G_Conf.patchPath, G_Patch.name, glue_savePatch, NULL);
 		gu_openSubWindow(mainWin, childWin, WID_FILE_BROWSER);
 		return;
 	}
 	if (strcmp(m->label(), "Save project...") == 0) {
-		gWindow *childWin = new gdBrowser("Save Project", G_Conf.patchPath.c_str(), 0, BROWSER_SAVE_PROJECT);
+		gWindow *childWin = new gdSaveBrowser(G_Conf.browserX, G_Conf.browserY,
+				G_Conf.browserW, G_Conf.browserH, "Save project",
+				G_Conf.patchPath, G_Patch.name, glue_saveProject, NULL);
 		gu_openSubWindow(mainWin, childWin, WID_FILE_BROWSER);
 		return;
 	}
