@@ -38,6 +38,7 @@
 #include "../../core/midiChannel.h"
 #include "../../glue/glue.h"
 #include "../../glue/channel.h"
+#include "../../glue/storage.h"
 #include "../../utils/gui_utils.h"
 #include "../dialogs/gd_mainWindow.h"
 #include "../dialogs/gd_keyGrabber.h"
@@ -366,20 +367,21 @@ void gSampleChannel::__cb_readActions()
 
 void gSampleChannel::openBrowser(int type)
 {
-	const char *title = "";
+	gWindow *childWin = NULL;
 	switch (type) {
 		case BROWSER_LOAD_SAMPLE:
-			title = "Browse Sample";
+			childWin = new gdLoadBrowser(G_Conf.browserX, G_Conf.browserY,
+					G_Conf.browserW, G_Conf.browserH, "Browse sample",
+					G_Conf.samplePath.c_str(), glue_loadSample, ch);
 			break;
 		case BROWSER_SAVE_SAMPLE:
-			title = "Save Sample";
-			break;
-		case -1:
-			title = "Edit Sample";
+			childWin = new gdSaveBrowser(G_Conf.browserX, G_Conf.browserY,
+					G_Conf.browserW, G_Conf.browserH, "Save sample", \
+					G_Conf.samplePath.c_str(), "", glue_saveSample, ch);
 			break;
 	}
-	gWindow *childWin = new gdBrowser(title, G_Conf.samplePath.c_str(), ch, type);
-	gu_openSubWindow(mainWin, childWin,	WID_FILE_BROWSER);
+	if (childWin)
+		gu_openSubWindow(mainWin, childWin,	WID_FILE_BROWSER);
 }
 
 
